@@ -27,6 +27,8 @@ CONDITIONS = {
     },
 }    
 
+class Error(Exception):
+    pass
 
 class KeyProperty(object):
     index = False
@@ -109,6 +111,53 @@ class UnicodeProperty(BaseProperty):
         return s.decode(self.internal_encoding, self.encoding_errors)
 
 
+class ChoiceProperty(UnicodeProperty):
+    '''
+        >>> choices = [
+        ...     ('1', 'first'),
+        ...     ('2', 'second'),
+        ... ]
+        >>> obj = ChoiceProperty(choices)
+        >>> obj.dumps('first')
+        '1'
+        >>> obj.loads('2')
+        'second'
+    '''
+    def __init__(self, choices, *args, **kwargs):
+        self.set_choices(choices)
+        super(self.__class__, self).__init__(*args, **kwargs)
+            
+    def set_choices(self, choices):
+        self.choices = []
+        self._choices_kv = {}
+        self._choices_vk = {}
+        for item in choices:
+            k, v = item if isinstance(item, (tuple, list)) else (item, item)
+            k = unicode(k)
+            if k in self._choices_kv:
+                raise Error(u'Duplicate choice key: %s' % k)
+            self.choices.append((k, v))
+            self._choices_kv[k] = v
+            self._choices_vk[v] = k
+
+    def dumps(self, value):
+        try:
+            value = self._choices_vk[value]
+        except KeyError:
+            raise Error(u'Unknown choice value. Allowed: %s' 
+                % ', '.join(self._choices_vk.keys()))
+        return super(self.__class__, self).dumps(value)
+
+    def loads(self, value):
+        ret = super(self.__class__, self).loads(value)
+        try:
+            ret = self._choices_kv[ret]
+        except KeyError:
+            raise Error(u'Unknown choice key. Allowed: %s' 
+                % ', '.join(self._choices_kv.keys()))
+        return ret
+
+
 class IntegerProperty(BaseProperty):
     '''
         >>> value = 10
